X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/f56d09146b7347e821757e76bd4a2996f36fd2ee..cf256f226b62fbd5bfbb08a6b0a10671386ce66c:/Controller/ApplicationController.php

diff --git a/Controller/ApplicationController.php b/Controller/ApplicationController.php
index 8a9a8b4..a6091cd 100644
--- a/Controller/ApplicationController.php
+++ b/Controller/ApplicationController.php
@@ -3,6 +3,7 @@
 namespace Rapsys\AirBundle\Controller;
 
 use Symfony\Component\HttpFoundation\Request;
+use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\RequestContext;
 use Symfony\Component\Form\FormError;
 use Symfony\Component\Routing\Exception\MethodNotAllowedException;
@@ -28,11 +29,6 @@ class ApplicationController extends DefaultController {
 		//Prevent non-guest to access here
 		$this->denyAccessUnlessGranted('ROLE_GUEST', null, $this->translator->trans('Unable to access this page without role %role%!', ['%role%' => $this->translator->trans('Guest')]));
 
-		//Reject non post requests
-		if (!$request->isMethod('POST')) {
-			throw new \RuntimeException('Request method MUST be POST');
-		}
-
 		//Create ApplicationType form
 		$form = $this->createForm('Rapsys\AirBundle\Form\ApplicationType', null, [
 			//Set the action
@@ -52,12 +48,12 @@ class ApplicationController extends DefaultController {
 		$form->handleRequest($request);
 
 		//Handle invalid form
-		if (!$form->isValid()) {
+		if (!$form->isSubmitted() || !$form->isValid()) {
 			//Set section
 			$section = $this->translator->trans('Application add');
 
 			//Set title
-			$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+			$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 			//Render the view
 			return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -72,15 +68,6 @@ class ApplicationController extends DefaultController {
 		//Get data
 		$data = $form->getData();
 
-		//Count session at location in last month for guest
-		if (!$this->isGranted('ROLE_REGULAR') && !empty($session = $doctrine->getRepository(Session::class)->findOneWithinLastMonthByLocationUser($data['location']->getId(), $this->getUser()->getId()))) {
-			//Add warning in flash message
-			$this->addFlash('warning', $this->translator->trans('Monthly application %location% already exists', ['%location%' => $this->translator->trans('at '.$data['location'])]));
-
-			//Redirect to cleanup the form
-			return $this->redirectToRoute('rapsys_air_session_view', ['id' => $session['id']]);
-		}
-
 		//Protect session fetching
 		try {
 			//Fetch session
@@ -138,21 +125,24 @@ class ApplicationController extends DefaultController {
 					$session->setLength(new \DateTime('05:00:00'));
 				//Check if afternoon
 				} elseif ($slot == 'Afternoon') {
-					//Set begin at 14h
-					$session->setBegin(new \DateTime('14:00:00'));
+					//Set begin at 16h
+					$session->setBegin(new \DateTime('16:00:00'));
 
-					//Set length at 5h
-					$session->setLength(new \DateTime('05:00:00'));
+					//Set length at 3h
+					$session->setLength(new \DateTime('03:00:00'));
 				//Check if evening
 				} elseif ($slot == 'Evening') {
 					//Set begin at 19h
-					$session->setBegin(new \DateTime('19:00:00'));
+					$session->setBegin(new \DateTime('19:30:00'));
 
 					//Check if next day is premium
 					if ($premium) {
 						//Set length at 7h
 						$session->setLength(new \DateTime('07:00:00'));
 					}
+
+					//Set length at 4h
+					$session->setLength(new \DateTime('04:30:00'));
 				//Check if after
 				} else {
 					//Set begin at 1h
@@ -290,6 +280,13 @@ class ApplicationController extends DefaultController {
 
 				//Set length at 4h
 				$session->setLength(new \DateTime('04:00:00'));
+			//Jardin du Monde => 14h -> 15h
+			} elseif ($short == 'Monde' && $slot == 'Morning') {
+				//Set begin at 14h
+				$session->setBegin(new \DateTime('14:00:00'));
+
+				//Set length at 4h
+				$session->setLength(new \DateTime('01:00:00'));
 			//Combination not supported
 			} else {
 				//Add error in flash message
@@ -299,7 +296,7 @@ class ApplicationController extends DefaultController {
 				$section = $this->translator->trans('Application add');
 
 				//Set title
-				$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+				$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 				//Render the view
 				return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -314,7 +311,7 @@ class ApplicationController extends DefaultController {
 				$section = $this->translator->trans('Application add');
 
 				//Set title
-				$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+				$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 				//Render the view
 				return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -407,8 +404,18 @@ class ApplicationController extends DefaultController {
 				//Remove route and controller from route defaults
 				unset($route['_route'], $route['_controller']);
 
+				//Check if session view route
+				if ($name == 'rapsys_air_session_view' && !empty($route['id'])) {
+					//Replace id
+					$route['id'] = $session->getId();
+				//Other routes
+				} else {
+					//Set session
+					$route['session'] = $session->getId();
+				}
+
 				//Generate url
-				return $this->redirectToRoute($name, ['session' => $session->getId()]+$route);
+				return $this->redirectToRoute($name, $route);
 			//No route matched
 			} catch(MethodNotAllowedException|ResourceNotFoundException $e) {
 				//Unset referer to fallback to default route